<?php

class Getback_Public
{

  /**
   * The ID of this plugin.
   *
   * @since    1.9.0
   * @access   private
   * @var      string    $plugin_name    The ID of this plugin.
   */
  private $plugin_name;

  /**
   * The settings options
   *
   * @since    1.9.0
   * @access   private
   * @var      array    $version    The current values of the settings options
   */
  private static $settings_options;

  /**
   * The version of this plugin.
   *
   * @since    1.9.0
   * @access   private
   * @var      string    $version    The current version of this plugin.
   */
  private $version;

  protected $loader;

  /**
   * Initialize the class and set its properties.
   *
   * @since    1.9.0
   * @param      string    $plugin_name       The name of the plugin.
   * @param      string    $version    The version of this plugin.
   */
  public function __construct($plugin_name, $version)
  {

    $this->plugin_name = $plugin_name;
    $this->version = $version;

    self::$settings_options = get_option('getback_options');

    $this->loader = new Getback_Loader;
  }


  /**
   * Register the stylesheets for the public-facing side of the site.
   *
   * @since    1.9.0
   */
  public function enqueue_styles()
  {
  }

  /**
   * Register the JavaScript for the public-facing side of the site.
   *
   * @since    1.9.0
   */
  public function enqueue_scripts()
  {
  }

  public function getback_toggler_script()
  {

    $is_plugin_active = self::$settings_options['onofftoggler'] ?? false;
    $is_unique_getback_id_set = !empty(self::$settings_options['unique_getback_id']);
    if ($is_plugin_active && $is_unique_getback_id_set) :
?>
      <script type="application/javascript" async src="https://www.getback.ch/<?php echo self::$settings_options['unique_getback_id']; ?>"></script>
      <script>
        window.gb_data = window.gb_data || [];

        function gb_send() {
          gb_data.push(arguments);
        }
      </script>
    <?php
    endif;
  }

  public function getback_conversion_toggler_script($order_id)
  {
    $order = new WC_Order($order_id);
    $is_conversion_checkbox_active = self::$settings_options['onofftoggler_conversion'];
    $is_unique_getback_id_set = !empty(self::$settings_options['unique_getback_id']);

    $getbackOrderTracked = get_post_meta($order->get_id(), '_getback_tracked', true);

    if ($is_conversion_checkbox_active && $is_unique_getback_id_set && Getback_Helper::woocommerce_is_active() && !$getbackOrderTracked) :

      $order_value = $order->get_total();
      $coupons = $order->get_coupon_codes();
      $currency = $order->get_currency();

      if (isset($coupons)) :
        foreach ($coupons as $coupon) :
          $voucher = $coupon;
          break;
        endforeach;
      endif;

    ?>
      <script async src="https://www.getback.ch/<?= self::$settings_options['unique_getback_id'] ?>/conversion/?ordervalue=<?= $order_value ?>&ordernumber=<?= $order_id ?><?php if (isset($voucher)) : print_r("&vouchercode=" . $voucher) ?><?php endif; ?>"></script>

<?php

    // Add or update post meta to make sure tracking is fired only once per order
    if (0 == $getbackOrderTracked){
      update_post_meta($order->get_id(), '_getback_tracked', true);
    }

    add_post_meta($order->get_id(), '_getback_tracked', true, true);
    endif;
  }
}
